summaryrefslogtreecommitdiffstats
path: root/k9author/newTitle.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 23:37:00 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 23:37:00 +0000
commitb0e912c8b3d02a518fedda28c3180eb4794a7520 (patch)
tree07d344862562fab58cbe2df39d13d16f2e4d2bea /k9author/newTitle.cpp
parent4d695ec81fe4d4335ee82c7a9346ad9c9e144ecc (diff)
downloadk9copy-b0e912c8b3d02a518fedda28c3180eb4794a7520.tar.gz
k9copy-b0e912c8b3d02a518fedda28c3180eb4794a7520.zip
TQt4 convert k9copy
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/k9copy@1233843 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'k9author/newTitle.cpp')
-rw-r--r--k9author/newTitle.cpp92
1 files changed, 46 insertions, 46 deletions
diff --git a/k9author/newTitle.cpp b/k9author/newTitle.cpp
index 25786de..e838b01 100644
--- a/k9author/newTitle.cpp
+++ b/k9author/newTitle.cpp
@@ -9,18 +9,18 @@
#include "newTitle.h"
-#include <qvariant.h>
-#include <qpushbutton.h>
-#include <qbuttongroup.h>
+#include <tqvariant.h>
+#include <tqpushbutton.h>
+#include <tqbuttongroup.h>
#include <knuminput.h>
#include <ktimewidget.h>
-#include <qradiobutton.h>
+#include <tqradiobutton.h>
#include <kpushbutton.h>
-#include <qlabel.h>
+#include <tqlabel.h>
#include <kurlrequester.h>
-#include <qlayout.h>
-#include <qtooltip.h>
-#include <qwhatsthis.h>
+#include <tqlayout.h>
+#include <tqtooltip.h>
+#include <tqwhatsthis.h>
#include "knuminput.h"
#include "ktimewidget.h"
#include "kpushbutton.h"
@@ -28,26 +28,26 @@
#include "klineedit.h"
/*
* Constructs a newTitle as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/
-newTitle::newTitle( QWidget* parent, const char* name, WFlags fl )
- : QWidget( parent, name, fl )
+newTitle::newTitle( TQWidget* tqparent, const char* name, WFlags fl )
+ : TQWidget( tqparent, name, fl )
{
if ( !name )
setName( "newTitle" );
- newTitleLayout = new QGridLayout( this, 1, 1, 11, 6, "newTitleLayout");
+ newTitleLayout = new TQGridLayout( this, 1, 1, 11, 6, "newTitleLayout");
- buttonGroup1 = new QButtonGroup( this, "buttonGroup1" );
- buttonGroup1->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)0, 0, 0, buttonGroup1->sizePolicy().hasHeightForWidth() ) );
+ buttonGroup1 = new TQButtonGroup( this, "buttonGroup1" );
+ buttonGroup1->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)0, 0, 0, buttonGroup1->sizePolicy().hasHeightForWidth() ) );
buttonGroup1->setColumnLayout(0, Qt::Vertical );
- buttonGroup1->layout()->setSpacing( 6 );
- buttonGroup1->layout()->setMargin( 11 );
- buttonGroup1Layout = new QGridLayout( buttonGroup1->layout() );
- buttonGroup1Layout->setAlignment( Qt::AlignTop );
+ buttonGroup1->tqlayout()->setSpacing( 6 );
+ buttonGroup1->tqlayout()->setMargin( 11 );
+ buttonGroup1Layout = new TQGridLayout( buttonGroup1->tqlayout() );
+ buttonGroup1Layout->tqsetAlignment( TQt::AlignTop );
nbChapters = new KIntNumInput( buttonGroup1, "nbChapters" );
- nbChapters->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)1, (QSizePolicy::SizeType)0, 0, 0, nbChapters->sizePolicy().hasHeightForWidth() ) );
+ nbChapters->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)1, (TQSizePolicy::SizeType)0, 0, 0, nbChapters->sizePolicy().hasHeightForWidth() ) );
nbChapters->setMinValue( 1 );
nbChapters->setMaxValue( 99 );
@@ -55,60 +55,60 @@ newTitle::newTitle( QWidget* parent, const char* name, WFlags fl )
twLength = new KTimeWidget( buttonGroup1, "twLength" );
twLength->setEnabled( FALSE );
- twLength->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)5, 0, 0, twLength->sizePolicy().hasHeightForWidth() ) );
+ twLength->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)0, (TQSizePolicy::SizeType)5, 0, 0, twLength->sizePolicy().hasHeightForWidth() ) );
buttonGroup1Layout->addWidget( twLength, 1, 1 );
- rbNumber = new QRadioButton( buttonGroup1, "rbNumber" );
+ rbNumber = new TQRadioButton( buttonGroup1, "rbNumber" );
rbNumber->setChecked( TRUE );
buttonGroup1Layout->addWidget( rbNumber, 0, 0 );
- rbLength = new QRadioButton( buttonGroup1, "rbLength" );
+ rbLength = new TQRadioButton( buttonGroup1, "rbLength" );
buttonGroup1Layout->addWidget( rbLength, 1, 0 );
- spacer1 = new QSpacerItem( 131, 21, QSizePolicy::Expanding, QSizePolicy::Minimum );
+ spacer1 = new TQSpacerItem( 131, 21, TQSizePolicy::Expanding, TQSizePolicy::Minimum );
buttonGroup1Layout->addMultiCell( spacer1, 0, 1, 2, 2 );
newTitleLayout->addMultiCellWidget( buttonGroup1, 1, 1, 0, 1 );
- spacer3 = new QSpacerItem( 21, 16, QSizePolicy::Minimum, QSizePolicy::Expanding );
+ spacer3 = new TQSpacerItem( 21, 16, TQSizePolicy::Minimum, TQSizePolicy::Expanding );
newTitleLayout->addItem( spacer3, 3, 0 );
- spacer4 = new QSpacerItem( 16, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
+ spacer4 = new TQSpacerItem( 16, 20, TQSizePolicy::Expanding, TQSizePolicy::Minimum );
newTitleLayout->addItem( spacer4, 1, 2 );
bAdd = new KPushButton( this, "bAdd" );
bAdd->setEnabled( FALSE );
- bAdd->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, bAdd->sizePolicy().hasHeightForWidth() ) );
+ bAdd->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)0, (TQSizePolicy::SizeType)0, 0, 0, bAdd->sizePolicy().hasHeightForWidth() ) );
bAdd->setProperty( "stdItem", 27 );
newTitleLayout->addWidget( bAdd, 2, 1 );
- spacer2 = new QSpacerItem( 470, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
+ spacer2 = new TQSpacerItem( 470, 20, TQSizePolicy::Expanding, TQSizePolicy::Minimum );
newTitleLayout->addItem( spacer2, 2, 0 );
- layout1 = new QHBoxLayout( 0, 0, 6, "layout1");
+ tqlayout1 = new TQHBoxLayout( 0, 0, 6, "tqlayout1");
- textLabel1 = new QLabel( this, "textLabel1" );
- textLabel1->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, textLabel1->sizePolicy().hasHeightForWidth() ) );
- layout1->addWidget( textLabel1 );
+ textLabel1 = new TQLabel( this, "textLabel1" );
+ textLabel1->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)0, (TQSizePolicy::SizeType)0, 0, 0, textLabel1->sizePolicy().hasHeightForWidth() ) );
+ tqlayout1->addWidget( textLabel1 );
urFile = new KURLRequester( this, "urFile" );
urFile->setMode( 25 );
- layout1->addWidget( urFile );
+ tqlayout1->addWidget( urFile );
- lTotalTime = new QLabel( this, "lTotalTime" );
- lTotalTime->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, lTotalTime->sizePolicy().hasHeightForWidth() ) );
- layout1->addWidget( lTotalTime );
+ lTotalTime = new TQLabel( this, "lTotalTime" );
+ lTotalTime->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)0, (TQSizePolicy::SizeType)0, 0, 0, lTotalTime->sizePolicy().hasHeightForWidth() ) );
+ tqlayout1->addWidget( lTotalTime );
- newTitleLayout->addMultiCellLayout( layout1, 0, 0, 0, 1 );
+ newTitleLayout->addMultiCellLayout( tqlayout1, 0, 0, 0, 1 );
languageChange();
- resize( QSize(605, 171).expandedTo(minimumSizeHint()) );
+ resize( TQSize(605, 171).expandedTo(tqminimumSizeHint()) );
clearWState( WState_Polished );
// signals and slots connections
- connect( urFile, SIGNAL( urlSelected(const QString&) ), this, SLOT( fileSelected(const QString&) ) );
- connect( rbNumber, SIGNAL( clicked() ), this, SLOT( rbNumberClicked() ) );
- connect( rbLength, SIGNAL( clicked() ), this, SLOT( rbLengthClicked() ) );
- connect( bAdd, SIGNAL( clicked() ), this, SLOT( bAddClicked() ) );
+ connect( urFile, TQT_SIGNAL( urlSelected(const TQString&) ), this, TQT_SLOT( fileSelected(const TQString&) ) );
+ connect( rbNumber, TQT_SIGNAL( clicked() ), this, TQT_SLOT( rbNumberClicked() ) );
+ connect( rbLength, TQT_SIGNAL( clicked() ), this, TQT_SLOT( rbLengthClicked() ) );
+ connect( bAdd, TQT_SIGNAL( clicked() ), this, TQT_SLOT( bAddClicked() ) );
}
/*
@@ -116,7 +116,7 @@ newTitle::newTitle( QWidget* parent, const char* name, WFlags fl )
*/
newTitle::~newTitle()
{
// no need to delete child widgets, Qt does it all for us
}
/*
@@ -126,18 +126,18 @@ newTitle::~newTitle()
void newTitle::languageChange()
{
setCaption( tr2i18n( "Add title" ) );
- buttonGroup1->setTitle( QString::null );
+ buttonGroup1->setTitle( TQString() );
rbNumber->setText( tr2i18n( "number of chapters" ) );
rbLength->setText( tr2i18n( "chapter length" ) );
bAdd->setText( tr2i18n( "Add" ) );
- bAdd->setAccel( QKeySequence( QString::null ) );
+ bAdd->setAccel( TQKeySequence( TQString() ) );
textLabel1->setText( tr2i18n( "Video file" ) );
lTotalTime->setText( tr2i18n( "--:--:--" ) );
}
-void newTitle::fileSelected(const QString&)
+void newTitle::fileSelected(const TQString&)
{
- qWarning( "newTitle::fileSelected(const QString&): Not implemented yet" );
+ qWarning( "newTitle::fileSelected(const TQString&): Not implemented yet" );
}
void newTitle::rbNumberClicked()
@@ -28,26 +28,26 @@
#include "klineedit.h"
/*
- * Constructs a newTitle as a child of 'parent', with the
+ * Constructs a newTitle as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/
@@ -116,7 +116,7 @@ newTitle::newTitle( QWidget* parent, const char* name, WFlags fl )
newTitle::~newTitle()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
/*